==> qt-creator-opensource-src-3.2.0.tar.gz: qt-creator-opensource-src-3.2.0/src/plugins/beautifier/clangformat/clangformatoptionspage.h <==
/**************************************************************************
**
** Copyright (c) 2014 Lorenz Haas
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef BEAUTIFIER_CLANGFORMATOPTIONSPAGE_H
#define BEAUTIFIER_CLANGFORMATOPTIONSPAGE_H

#include <coreplugin/dialogs/ioptionspage.h>
#include <utils/qtcoverride.h>

#include <QPointer>
#include <QWidget>

namespace Beautifier {
namespace Internal {
namespace ClangFormat {

class ClangFormatSettings;

namespace Ui { class ClangFormatOptionsPage; }

class ClangFormatOptionsPageWidget : public QWidget
{
    Q_OBJECT

public:
    explicit ClangFormatOptionsPageWidget(ClangFormatSettings *settings, QWidget *parent = 0);
    virtual ~ClangFormatOptionsPageWidget();
    void restore();
    void apply();

private:
    Ui::ClangFormatOptionsPage *ui;
    ClangFormatSettings *m_settings;
};

class ClangFormatOptionsPage : public Core::IOptionsPage
{
    Q_OBJECT

public:
    explicit ClangFormatOptionsPage(ClangFormatSettings *settings, QObject *parent = 0);
    QWidget *widget() QTC_OVERRIDE;
    void apply() QTC_OVERRIDE;
    void finish() QTC_OVERRIDE;

private:
    QPointer<ClangFormatOptionsPageWidget> m_widget;
    ClangFormatSettings *m_settings;
};

} // namespace ClangFormat
} // namespace Internal
} // namespace Beautifier

#endif // BEAUTIFIER_CLANGFORMATOPTIONSPAGE_H

==> qt-creator-opensource-src-3.3.0.tar.gz: qt-creator-opensource-src-3.3.0/src/plugins/beautifier/clangformat/clangformatoptionspage.h <==
/**************************************************************************
**
** Copyright (c) 2014 Lorenz Haas
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef BEAUTIFIER_CLANGFORMATOPTIONSPAGE_H
#define BEAUTIFIER_CLANGFORMATOPTIONSPAGE_H

#include <coreplugin/dialogs/ioptionspage.h>

#include <QPointer>
#include <QWidget>

namespace Beautifier {
namespace Internal {
namespace ClangFormat {

class ClangFormatSettings;

namespace Ui { class ClangFormatOptionsPage; }

class ClangFormatOptionsPageWidget : public QWidget
{
    Q_OBJECT

public:
    explicit ClangFormatOptionsPageWidget(ClangFormatSettings *settings, QWidget *parent = 0);
    virtual ~ClangFormatOptionsPageWidget();
    void restore();
    void apply();

private:
    Ui::ClangFormatOptionsPage *ui;
    ClangFormatSettings *m_settings;
};

class ClangFormatOptionsPage : public Core::IOptionsPage
{
    Q_OBJECT

public:
    explicit ClangFormatOptionsPage(ClangFormatSettings *settings, QObject *parent = 0);
    QWidget *widget() Q_DECL_OVERRIDE;
    void apply() Q_DECL_OVERRIDE;
    void finish() Q_DECL_OVERRIDE;

private:
    QPointer<ClangFormatOptionsPageWidget> m_widget;
    ClangFormatSettings *m_settings;
};

} // namespace ClangFormat
} // namespace Internal
} // namespace Beautifier

#endif // BEAUTIFIER_CLANGFORMATOPTIONSPAGE_H
